@@ -27,9 +27,10 @@
 #include <kcontacts/addressee.h>
 #include <KPluginTrader>
 #include <QHBoxLayout>
+#include <kcoreaddons_version.h>
+#include <kpluginfactory.h>
 
-K_PLUGIN_FACTORY_WITH_JSON(CategoriesEditWidgetFactory, "categorieseditwidgetplugin.json", registerPlugin<CategoriesEditWidget>();
-                           )
+K_PLUGIN_CLASS_WITH_JSON(CategoriesEditWidget, "categorieseditwidgetplugin.json")
 
 CategoriesEditWidget::CategoriesEditWidget(QWidget *parent, const QList<QVariant> &)
     : ContactEditor::CategoriesEditAbstractWidget(parent)
